package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseTeamMembersMapper;
import com.aucma.base.domain.BaseTeamMembers;
import com.aucma.base.service.IBaseTeamMembersService;

/**
 * 班组信息Service业务层处理
 * 
 * @author Yinq
 * @date 2023-09-19
 */
@Service
public class BaseTeamMembersServiceImpl implements IBaseTeamMembersService 
{
    @Autowired
    private BaseTeamMembersMapper baseTeamMembersMapper;

    /**
     * 查询班组信息
     * 
     * @param objId 班组信息主键
     * @return 班组信息
     */
    @Override
    public BaseTeamMembers selectBaseTeamMembersByObjId(Long objId)
    {
        return baseTeamMembersMapper.selectBaseTeamMembersByObjId(objId);
    }

    /**
     * 查询班组信息列表
     * 
     * @param baseTeamMembers 班组信息
     * @return 班组信息
     */
    @Override
    public List<BaseTeamMembers> selectBaseTeamMembersList(BaseTeamMembers baseTeamMembers)
    {
        return baseTeamMembersMapper.selectBaseTeamMembersList(baseTeamMembers);
    }

    /**
     * 新增班组信息
     * 
     * @param baseTeamMembers 班组信息
     * @return 结果
     */
    @Override
    public int insertBaseTeamMembers(BaseTeamMembers baseTeamMembers)
    {
        return baseTeamMembersMapper.insertBaseTeamMembers(baseTeamMembers);
    }

    /**
     * 修改班组信息
     * 
     * @param baseTeamMembers 班组信息
     * @return 结果
     */
    @Override
    public int updateBaseTeamMembers(BaseTeamMembers baseTeamMembers)
    {
        return baseTeamMembersMapper.updateBaseTeamMembers(baseTeamMembers);
    }

    /**
     * 批量删除班组信息
     * 
     * @param objIds 需要删除的班组信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseTeamMembersByObjIds(Long[] objIds)
    {
        return baseTeamMembersMapper.deleteBaseTeamMembersByObjIds(objIds);
    }

    /**
     * 删除班组信息信息
     * 
     * @param objId 班组信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseTeamMembersByObjId(Long objId)
    {
        return baseTeamMembersMapper.deleteBaseTeamMembersByObjId(objId);
    }
}
